@@ -34,8 +34,6 @@
 #include <wangle/acceptor/SecurityProtocolContextManager.h>
 #include <wangle/ssl/SSLContextManager.h>
 
-#include <fstream>
-
 using folly::AsyncServerSocket;
 using folly::AsyncSocket;
 using folly::AsyncSSLSocket;
@@ -155,7 +153,10 @@ void Acceptor::initDownstreamConnectionManager(EventBase* eventBase) {
 }
 
 std::shared_ptr<fizz::server::FizzServerContext> Acceptor::createFizzContext() {
-  return FizzConfigUtil::createFizzContext(accConfig_);
+  return FizzConfigUtil::createFizzContext(
+      accConfig_.sslContextConfigs,
+      accConfig_.fizzConfig,
+      accConfig_.strictSSL);
 }
 
 std::shared_ptr<fizz::server::FizzServerContext>
@@ -190,7 +191,10 @@ std::shared_ptr<fizz::server::TicketCipher> Acceptor::createFizzTicketCipher(
 }
 
 std::unique_ptr<fizz::server::CertManager> Acceptor::createFizzCertManager() {
-  return FizzConfigUtil::createCertManager(accConfig_, nullptr);
+  return FizzConfigUtil::createCertManager(
+      accConfig_.sslContextConfigs,
+      /* pwFactory = */ nullptr,
+      accConfig_.strictSSL);
 }
 
 std::string Acceptor::getPskContext() {
@@ -233,7 +237,61 @@ void Acceptor::resetSSLContextConfigs(
   }
 }
 
-Acceptor::~Acceptor(void) {}
+void Acceptor::resetSSLContextConfigs(
+    const std::vector<SSLContextConfig>& sslContextConfigs) {
+  std::shared_ptr<fizz::server::CertManager> certManager = nullptr;
+  std::shared_ptr<SSLContextManager> ctxManager = nullptr;
+  std::shared_ptr<const fizz::server::FizzServerContext> fizzContext = nullptr;
+  try {
+    if (accConfig_.fizzConfig.enableFizz) {
+      certManager = FizzConfigUtil::createCertManager(
+          sslContextConfigs,
+          /* pwFactory = */ nullptr,
+          accConfig_.strictSSL);
+      if (certManager) {
+        auto context = createFizzContext();
+        if (context) {
+          context->setCertManager(certManager);
+          std::string pskContext;
+          if (!sslContextConfigs.empty()) {
+            pskContext = sslContextConfigs.front().sessionContext.value_or("");
+          }
+          context->setTicketCipher(createFizzTicketCipher(
+              ticketSecrets_,
+              context->getFactoryPtr(),
+              certManager,
+              std::move(pskContext)));
+        }
+        fizzContext = std::move(context);
+      }
+    }
+    if (sslCtxManager_) {
+      // The API only updates sslContextConfigs, this API should be only called
+      // for acceptors that hos no SNI configs
+      DCHECK(accConfig_.sniConfigs.empty());
+      sslCtxManager_->resetSSLContextConfigs(
+          sslContextConfigs,
+          accConfig_.sniConfigs,
+          accConfig_.sslCacheOptions,
+          nullptr,
+          accConfig_.bindAddress,
+          cacheProvider_);
+    }
+    resetSSLContextConfigs(certManager, sslCtxManager_, fizzContext);
+  } catch (const std::runtime_error& ex) {
+    LOG(ERROR) << "Failed to re-configure TLS: " << ex.what()
+               << "will keep old config";
+  }
+}
+
+void Acceptor::reloadSSLContextConfigs() {
+  resetSSLContextConfigs(
+      /* certManager = */ nullptr,
+      /* ctxManager = */ nullptr,
+      /* fizzContext = */ nullptr);
+}
+
+Acceptor::~Acceptor() = default;
 
 void Acceptor::setTLSTicketSecrets(
     const std::vector<std::string>& oldSecrets,
